==> rich-text-editor-2.9.8.tgz: package/src/utils/tools.js <==
import _ from 'lodash';
import { fontSize, fontFamily } from '../constants';

export const getTools = [
  {
    id: 1,
    name: 'bold',
    field_type: 'button',
    aria: 'bold',
    tagNames: 'b',
    style: {
      prop: 'font-weight',
      value: 'bold',
    },
    contentDefault: 'B',
    contentFA: 'fas fa-bold',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 2,
    name: 'italic',
    field_type: 'button',
    aria: 'italic',
    tagNames: 'i',
    style: {
      prop: 'font-style',
      value: 'italic',
    },
    contentDefault: 'I',
    contentFA: 'fas fa-italic',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 3,
    name: 'underline',
    field_type: 'button',
    aria: 'underline',
    tagNames: 'u',
    style: {
      prop: 'text-decoration',
      value: 'underline',
    },
    contentDefault: 'U',
    contentFA: 'fas fa-underline',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 4,
    name: 'createlink',
    field_type: 'button',
    aria: 'link',
    tagNames: 'link',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'Link',
    contentFA: 'fas fa-link',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 5,
    name: 'unlink',
    field_type: 'button',
    aria: 'unlink',
    tagNames: 'unlink',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'Unline',
    contentFA: 'fas fa-unlink',
    appearance: 'unlink',
    isEnable: true,
  },
  {
    id: 6,
    name: 'strikethrough',
    field_type: 'button',
    aria: 'strike through',
    tagNames: 'strike',
    style: {
      prop: 'text-decoration',
      value: 'line-through',
    },
    contentDefault: '<s>A</s>',
    contentFA: 'fas fa-strikethrough',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 7,
    name: 'image',
    field_type: 'file',
    aria: 'image',
    tagNames: 'img',
    style: {},
    contentDefault: 'image',
    contentFA: 'far fa-image',
    appearance: 'link',
    isEnable: false,
  },
  {
    id: 8,
    name: 'insertorderedlist',
    field_type: 'button',
    aria: 'ordered list',
    tagNames: 'ol',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '1.',
    contentFA: 'fas fa-list-ol',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 9,
    name: 'insertunorderedlist',
    field_type: 'button',
    aria: 'unordered list',
    tagNames: 'ul',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '&bull;',
    contentFA: 'fas fa-list-ul',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 10,
    name: 'formatblock',
    field_type: 'button',
    aria: 'formatblock',
    tagNames: 'blockquote',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '',
    contentFA: 'fas fa-quote-left',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 11,
    name: 'cut',
    field_type: 'button',
    aria: 'cut',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'C',
    contentFA: 'fas fa-cut',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 12,
    name: 'copy',
    field_type: 'button',
    aria: 'copy',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'C',
    contentFA: 'fas fa-copy',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 13,
    name: 'print',
    field_type: 'button',
    aria: 'print',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '',
    contentFA: 'fas fa-print',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 14,
    name: 'pre',
    field_type: 'button',
    aria: 'preformatted text',
    tagNames: 'pre',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '0101',
    contentFA: 'fas fa-code',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 15,
    name: 'header',
    field_type: 'select',
    aria: 'header',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    suggest: {
      name: 'title',
      value: 'value',
      options: _.map(_.range(1, 7), (item) => (
        { title: `Heading ${item}`, value: `${item}` }
      )),
      style: 'formatblock',
    },
    contentDefault: 'Header',
    contentFA: '',
    appearance: 'button',
    isEnable: true,
  },
  {
    id: 16,
    name: 'fontFamily',
    field_type: 'select',
    aria: 'font family',
    tagNames: '',
    style: {
      prop: 'font-family',
      value: '',
    },
    suggest: {
      name: 'title',
      value: 'value',
      options: _.map(fontFamily, (item) => (
        { title: item, value: item }
      )),
      style: 'fontname',
    },
    contentDefault: 'Font',
    contentFA: '',
    appearance: 'button',
    isEnable: true,
  },
  {
    id: 17,
    name: 'fontSize',
    field_type: 'select',
    aria: 'font size',
    tagNames: '',
    style: {
      prop: 'font-size',
      value: '',
    },
    suggest: {
      name: 'title',
      value: 'value',
      options: _.map(fontSize, (item, index) => (
        { title: item, value: index + 1 }
      )),
      style: 'fontsize',
    },
    contentDefault: 'Size',
    contentFA: '',
    appearance: 'button',
    isEnable: true,
  },
  {
    id: 18,
    name: 'selectAll',
    field_type: 'button',
    aria: 'select all',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '',
    contentFA: 'fas fa-clipboard-list',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 19,
    name: 'textColor',
    field_type: 'color-picker',
    aria: 'text color picker',
    tagNames: '',
    style: {
      prop: 'forecolor',
      value: '',
    },
    contentDefault: 'A',
    contentFA: 'fas fa-font',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 20,
    name: 'backgroundColor',
    field_type: 'color-picker',
    aria: 'background color picker',
    tagNames: '',
    style: {
      prop: 'backcolor',
      value: '',
    },
    contentDefault: 'A',
    contentFA: 'fas fa-fill-drip',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 21,
    name: 'removeFormat',
    field_type: 'button',
    aria: 'remove format',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'Eraser',
    contentFA: 'fas fa-eraser',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 22,
    name: 'trash',
    field_type: 'button',
    aria: 'clean',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'Clean',
    contentFA: 'fas fa-trash',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 23,
    name: 'insertHorizontalRule',
    field_type: 'button',
    aria: 'divider',
    tagNames: 'hr',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'Divider',
    contentFA: 'fas fa-divide',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 24,
    name: 'justifyLeft',
    field_type: 'button',
    aria: 'left justify',
    tagNames: '',
    style: {
      prop: 'text-align',
      value: 'left',
    },
    contentDefault: 'L',
    contentFA: 'fas fa-align-left',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 25,
    name: 'justifyCenter',
    field_type: 'button',
    aria: 'center justify',
    tagNames: '',
    style: {
      prop: 'text-align',
      value: 'center',
    },
    contentDefault: 'C',
    contentFA: 'fas fa-align-center',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 26,
    name: 'justifyRight',
    field_type: 'button',
    aria: 'right justify',
    tagNames: '',
    style: {
      prop: 'text-align',
      value: 'right',
    },
    contentDefault: 'R',
    contentFA: 'fas fa-align-right',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 27,
    name: 'outdent',
    field_type: 'button',
    aria: 'outdent',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '',
    contentFA: 'fas fa-outdent',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 28,
    name: 'indent',
    field_type: 'button',
    aria: 'indent',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '',
    contentFA: 'fas fa-indent',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 29,
    name: 'undo',
    field_type: 'button',
    aria: 'undo',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'U',
    contentFA: 'fas fa-undo',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 30,
    name: 'redo',
    field_type: 'button',
    aria: 'redo',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'R',
    contentFA: 'fas fa-redo',
    appearance: 'link',
    isEnable: true,
  },
];

==> rich-text-editor-3.0.5.tgz: package/src/utils/tools.js <==
import _ from 'lodash';
import { fontSize, fontFamily } from '../constants';

export const getTools = [
  {
    id: 1,
    name: 'bold',
    field_type: 'button',
    aria: 'bold',
    tagNames: 'b',
    style: {
      prop: 'font-weight',
      value: 'bold',
    },
    contentDefault: 'B',
    contentFA: 'fas fa-bold',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 2,
    name: 'italic',
    field_type: 'button',
    aria: 'italic',
    tagNames: 'i',
    style: {
      prop: 'font-style',
      value: 'italic',
    },
    contentDefault: 'I',
    contentFA: 'fas fa-italic',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 3,
    name: 'underline',
    field_type: 'button',
    aria: 'underline',
    tagNames: 'u',
    style: {
      prop: 'text-decoration',
      value: 'underline',
    },
    contentDefault: 'U',
    contentFA: 'fas fa-underline',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 4,
    name: 'createlink',
    field_type: 'button',
    aria: 'link',
    tagNames: 'link',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'Link',
    contentFA: 'fas fa-link',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 5,
    name: 'unlink',
    field_type: 'button',
    aria: 'unlink',
    tagNames: 'unlink',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'Unline',
    contentFA: 'fas fa-unlink',
    appearance: 'unlink',
    isEnable: true,
  },
  {
    id: 6,
    name: 'strikethrough',
    field_type: 'button',
    aria: 'strike through',
    tagNames: 'strike',
    style: {
      prop: 'text-decoration',
      value: 'line-through',
    },
    contentDefault: '<s>A</s>',
    contentFA: 'fas fa-strikethrough',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 7,
    name: 'image',
    field_type: 'file',
    aria: 'image',
    tagNames: 'img',
    style: {},
    contentDefault: 'image',
    contentFA: 'far fa-image',
    appearance: 'link',
    isEnable: false,
  },
  {
    id: 8,
    name: 'insertorderedlist',
    field_type: 'button',
    aria: 'ordered list',
    tagNames: 'ol',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '1.',
    contentFA: 'fas fa-list-ol',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 9,
    name: 'insertunorderedlist',
    field_type: 'button',
    aria: 'unordered list',
    tagNames: 'ul',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '&bull;',
    contentFA: 'fas fa-list-ul',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 10,
    name: 'formatblock',
    field_type: 'button',
    aria: 'formatblock',
    tagNames: 'blockquote',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '',
    contentFA: 'fas fa-quote-left',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 11,
    name: 'cut',
    field_type: 'button',
    aria: 'cut',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'C',
    contentFA: 'fas fa-cut',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 12,
    name: 'copy',
    field_type: 'button',
    aria: 'copy',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'C',
    contentFA: 'fas fa-copy',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 13,
    name: 'print',
    field_type: 'button',
    aria: 'print',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '',
    contentFA: 'fas fa-print',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 14,
    name: 'pre',
    field_type: 'button',
    aria: 'preformatted text',
    tagNames: 'pre',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '0101',
    contentFA: 'fas fa-code',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 15,
    name: 'header',
    field_type: 'select',
    aria: 'header',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    suggest: {
      name: 'title',
      value: 'value',
      options: _.map(_.range(1, 7), (item) => (
        { title: `Heading ${item}`, value: `${item}`, isActive: true }
      )),
      style: 'formatblock',
    },
    contentDefault: 'Header',
    contentFA: '',
    appearance: 'button',
    isEnable: true,
  },
  {
    id: 16,
    name: 'fontFamily',
    field_type: 'select',
    aria: 'font family',
    tagNames: '',
    style: {
      prop: 'font-family',
      value: '',
    },
    suggest: {
      name: 'title',
      value: 'value',
      options: _.map(fontFamily, (item) => (
        { title: item, value: item, isActive: true }
      )),
      style: 'fontname',
    },
    contentDefault: 'Font',
    contentFA: '',
    appearance: 'button',
    isEnable: true,
  },
  {
    id: 17,
    name: 'fontSize',
    field_type: 'select',
    aria: 'font size',
    tagNames: '',
    style: {
      prop: 'font-size',
      value: '',
    },
    suggest: {
      name: 'title',
      value: 'value',
      options: _.map(fontSize, (item, index) => (
        { title: item, value: index + 1, isActive: true }
      )),
      style: 'fontsize',
    },
    contentDefault: 'Size',
    contentFA: '',
    appearance: 'button',
    isEnable: true,
  },
  {
    id: 18,
    name: 'selectAll',
    field_type: 'button',
    aria: 'select all',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '',
    contentFA: 'fas fa-clipboard-list',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 19,
    name: 'textColor',
    field_type: 'color-picker',
    aria: 'text color picker',
    tagNames: '',
    style: {
      prop: 'forecolor',
      value: '',
    },
    contentDefault: 'A',
    contentFA: 'fas fa-font',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 20,
    name: 'backgroundColor',
    field_type: 'color-picker',
    aria: 'background color picker',
    tagNames: '',
    style: {
      prop: 'backcolor',
      value: '',
    },
    contentDefault: 'A',
    contentFA: 'fas fa-fill-drip',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 21,
    name: 'removeFormat',
    field_type: 'button',
    aria: 'remove format',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'Eraser',
    contentFA: 'fas fa-eraser',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 22,
    name: 'trash',
    field_type: 'button',
    aria: 'clean',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'Clean',
    contentFA: 'fas fa-trash',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 23,
    name: 'insertHorizontalRule',
    field_type: 'button',
    aria: 'divider',
    tagNames: 'hr',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'Divider',
    contentFA: 'fas fa-divide',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 24,
    name: 'justifyLeft',
    field_type: 'button',
    aria: 'left justify',
    tagNames: '',
    style: {
      prop: 'text-align',
      value: 'left',
    },
    contentDefault: 'L',
    contentFA: 'fas fa-align-left',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 25,
    name: 'justifyCenter',
    field_type: 'button',
    aria: 'center justify',
    tagNames: '',
    style: {
      prop: 'text-align',
      value: 'center',
    },
    contentDefault: 'C',
    contentFA: 'fas fa-align-center',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 26,
    name: 'justifyRight',
    field_type: 'button',
    aria: 'right justify',
    tagNames: '',
    style: {
      prop: 'text-align',
      value: 'right',
    },
    contentDefault: 'R',
    contentFA: 'fas fa-align-right',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 27,
    name: 'outdent',
    field_type: 'button',
    aria: 'outdent',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '',
    contentFA: 'fas fa-outdent',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 28,
    name: 'indent',
    field_type: 'button',
    aria: 'indent',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: '',
    contentFA: 'fas fa-indent',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 29,
    name: 'undo',
    field_type: 'button',
    aria: 'undo',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'U',
    contentFA: 'fas fa-undo',
    appearance: 'link',
    isEnable: true,
  },
  {
    id: 30,
    name: 'redo',
    field_type: 'button',
    aria: 'redo',
    tagNames: '',
    style: {
      prop: '',
      value: '',
    },
    contentDefault: 'R',
    contentFA: 'fas fa-redo',
    appearance: 'link',
    isEnable: true,
  },
];
